@@ -1,4 +1,4 @@
-__version__ = "0.0.2"
+__version__ = "0.0.4"
 __keywords__ = ["python cgi apache"]
 
 
@@ -10,5 +10,5 @@ __keywords__ = ["python cgi apache"]
 #     os._exit(1)
 
 
-from .core import *
+from .core import _SERVER, _GET, _POST, _SESSION, _COOKIE, _HEADERS, set_status, set_header, execute, print
 
